<?php
/*
 * Copyright (C) 2022 Intergo Telecom Ltd <support@sms.to>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Joomla\Plugin\Actionlog\Joomlasmsto\Traits;

use Joomla\Component\Actionlogs\Administrator\Helper\ActionlogsHelper;

// Protect from unauthorized access
\defined('_JEXEC') or die();

/**
 * Handle on user login
 *
 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
 */
trait ContentAfterDelete
{
	/**
	 * After delete content logging method
	 * This method adds a record to #__action_logs contains (message, date, context, user)
	 * Method is called right after the content is deleted
	 *
	 * @param   string  $context  The context of the content passed to the plugin
	 * @param   object  $article  A JTableContent object
	 *
	 * @return  void
	 *
	 */
	public function onContentAfterDelete($context, $article): void
	{
		if (!$this->params->get('content_after_delete')) {
			return;
		}

		$option = $this->app->input->get('option');

		if (!$this->checkLoggable($option)) {
			return;
		}

		$params = ActionlogsHelper::getLogContentTypeParams($context);

		// Not found a valid content type, don't process further
		if ($params === null) {
			return;
		}

		// If the content type has it own language key, use it, otherwise, use default language key
		if ($this->app->getLanguage()->hasKey(strtoupper($params->text_prefix . '_' . $params->type_title . '_DELETED'))) {
			$messageLanguageKey = $params->text_prefix . '_' . $params->type_title . '_DELETED';
		} else {
			$messageLanguageKey = 'PLG_SYSTEM_ACTIONLOGS_CONTENT_DELETED';
		}

		$id = empty($params->id_holder) ? 0 : $article->get($params->id_holder);

		$message = array(
			'action' => 'delete',
			'type'   => $params->text_prefix . '_TYPE_' . $params->type_title,
			'id'     => $id,
			'title'  => $article->get($params->title_holder),
		);

		$this->addLog(array($message), $messageLanguageKey, $context);
	}

}